@@ -173,6 +173,24 @@ int isRegularFile(std::string fname, bool *is_reg) {
   return 0;
 }
 
+int isReadOnlyForAll(const std::string& fname, bool *is_read_only){
+  struct stat file_stat;
+  int ret;
+
+  ret = stat(fname.c_str(), &file_stat);
+  if (ret) {
+    return errno;
+  }
+
+  if (is_read_only != nullptr) {
+    *is_read_only = (file_stat.st_mode & (S_IRUSR | S_IRGRP | S_IROTH)) && !(file_stat.st_mode & (S_IWUSR | S_IWGRP | S_IWOTH));
+  } else {
+    ret = 1;
+  }
+
+  return ret;
+}
+
 int WriteSysfsStr(std::string path, std::string val) {
   //  On success, zero is returned.  On error, -1 is returned, and
   //  errno is set to indicate the error.
@@ -1175,11 +1193,13 @@ rsmi_status_t rsmi_get_gfx_target_version(uint32_t dv_ind, std::string *gfx_vers
     // separate out parts -> put back into normal graphics version format
     major = static_cast<uint64_t>((orig_target_version / 10000) * 100);
     minor = static_cast<uint64_t>((orig_target_version % 10000 / 100) * 10);
-    if ((minor == 0) && (countDigit(major) < 4)) {
-      major *= 10;  // 0 as a minor is correct, but bump up by 10
-    }
     rev = static_cast<uint64_t>(orig_target_version % 100);
-    *gfx_version = "gfx" + std::to_string(major + minor + rev);
+
+    ss << std::hex << rev;
+    std::string revision = ss.str();
+    *gfx_version = "gfx" + std::to_string((major + minor)/10) + revision;
+
+    ss.str("");
     ss << __PRETTY_FUNCTION__
     << " | " << std::dec << "kfd_target_version = " << orig_target_version
     << "; major = " << major << "; minor = " << minor << "; rev = "
@@ -1245,5 +1265,26 @@ int countDigit(uint64_t n) {
   return static_cast<int>(std::floor(log10(n) + 1));
 }
 
+std::string find_file_in_folder(const std::string& folder,
+               const std::string& regex) {
+  std::string file_name;
+  // TODO(amdsmi_dev): The closedir function has some non-standard attributes
+  // that are being ignored here which is causing a warning to be thrown
+  using dir_ptr = std::unique_ptr<DIR, decltype(&closedir)>;
+
+  struct dirent *dir = nullptr;
+  std::regex file_regex(regex);
+  auto drm_dir = dir_ptr(opendir(folder.c_str()), &closedir);
+  if (drm_dir == nullptr) return file_name;
+  std::cmatch m;
+  while ((dir = readdir(drm_dir.get())) != NULL) {
+    if (std::regex_search(dir->d_name, m, file_regex)) {
+        file_name = dir->d_name;
+        break;
+    }
+  }
+  return file_name;
+}
+
 }  // namespace smi
 }  // namespace amd
